pub fn effective_ceiling(
current: &CapabilitySet,
names: &[Symbol],
) -> Result<CapabilitySet>Expand description
Resolves capability symbols and intersects them with the active set.
pub fn effective_ceiling(
current: &CapabilitySet,
names: &[Symbol],
) -> Result<CapabilitySet>Resolves capability symbols and intersects them with the active set.