pub fn terminal_model_content(response: &ModelResponse) -> Result<&Expr>Expand description
Returns the terminal content item from a model response.
pub fn terminal_model_content(response: &ModelResponse) -> Result<&Expr>Returns the terminal content item from a model response.